@@ -20,6 +20,7 @@ from inforion.transformation.transform import tranform_data
 #from inforion.ionapi.MMS import AddItmBasic,MMS021,MMS021bulk,MMS021bulk2,execute,executeSnd,executeAsyncSnd
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *  
+from inforion.excelexport import *
 
 
 from inforion.helper.urlsplit import spliturl
@@ -119,6 +120,16 @@ def main():
             
             if "Bearer" in headers['Authorization']:
                 return "InforION Login is working"
+   
+    elif typ == 'E':
+        if not program:
+            print('\033[91m' + "Please pass program (API endpoint) name with param -p or --program CRS610MI" + '\033[0m')
+        if not outputfile:
+            print('\033[91m' + "Please pass output file name with param -o or --outputfile CRS610MI" + '\033[0m')
+ 
+        if(program and outputfile):
+            generate_api_template_file(program, outputfile)
+
     else:
         inputdata = pd.read_excel(inputfile)
         return tranform_data(mappingfile,mainsheet,inputdata,outputfile)
