@@ -34,8 +34,8 @@ MaxChunk = 150
 
 
 def execute(url,headers,program,methode,inputfile,outputfile=None,start=0,end=None):
-    df = pd.read_excel(inputfile)
-    
+    df = pd.read_csv(inputfile)
+    #df = pd.read_excel(inputfile)
     
 
     data = {'program': program,
@@ -111,13 +111,15 @@ def execute(url,headers,program,methode,inputfile,outputfile=None,start=0,end=No
 
     if outputfile is not None:
         print ('Save to file: ' + outputfile)
-        writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
-        df.to_excel(writer, sheet_name='Log Output',index=False)
-        writer.save()
+        df.to_csv(outputfile)
+        #writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
+        #df.to_excel(writer, sheet_name='Log Output',index=False)
+        #writer.save()
     
 def executeSnd(url,headers,program,methode,inputfile,outputfile=None,start=0,end=None):
     
-    df = pd.read_excel("newoutput.xlsx")
+    #df = pd.read_excel("newoutput.xlsx")
+    df = pd.read_csv("newoutput.csv")
     #, true_values = ['Yes'], false_values = ['No']
     
 
@@ -182,17 +184,16 @@ def executeSnd(url,headers,program,methode,inputfile,outputfile=None,start=0,end
 
     if outputfile is not None:
         print ('Save to file: ' + outputfile)
-        writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
-        df.to_excel(writer, sheet_name='Log Output',index=False)
-        writer.save()
-
-
-
+        df.to_csv(outputfile)
+        #writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
+        #df.to_excel(writer, sheet_name='Log Output',index=False)
+        #writer.save()
 
 def executeAsyncSnd(url,headers,program,methode,inputfile,outputfile=None,start=0,end=None):
 
-    df = pd.read_excel("newoutput.xlsx", true_values = ['Yes'], false_values = ['No'] )
-    
+    df = pd.read_csv("newoutput.csv", true_values = ['Yes'], false_values = ['No'] )
+    #df = pd.read_excel("newoutput.xlsx", true_values = ['Yes'], false_values = ['No'] )
+        
     data = {'program': program,
             'cono':    409 }
         
@@ -262,7 +263,8 @@ def executeAsyncSnd(url,headers,program,methode,inputfile,outputfile=None,start=
     
     if outputfile is not None:
         print ('Save to file: ' + outputfile)
-        writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
-        df.to_excel(writer, sheet_name='Log Output',index=False)
-        writer.save()
+        df.to_csv(outputfile)
+        #writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
+        #df.to_excel(writer, sheet_name='Log Output',index=False)
+        #writer.save()
     
\ No newline at end of file
